@@ -1,18 +1,18 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* This file is part of the GtkHTML library.
-
+   
    Copyright (C) 2000 Helix Code, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
-
+   
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
-
+   
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
@@ -30,8 +30,8 @@
 
 struct _HTMLFrame {
 	HTMLEmbedded embedded;
-
-	gchar *url;
+	
+	char *url;
 	GtkWidget *scroll;
 	GtkWidget *html;
 	HTMLPainter *gdk_painter;
@@ -65,16 +65,19 @@ void           html_frame_set_scrolling         (HTMLFrame *frame,
 void           html_frame_init                  (HTMLFrame        *frame,
 						 HTMLFrameClass   *klass,
 						 GtkWidget         *parent,
-						 gchar              *url,
+						 char              *url,
 						 gint               width,
 						 gint               height,
 						 gboolean           border);
 
 HTMLObject *   html_frame_new                   (GtkWidget *parent,
-						 gchar *src,
+						 char *src,
 						 gint width,
 						 gint height,
 						 gboolean border);
 
+						  
+						  
 #endif
 
+
